@@ -94,6 +94,9 @@ do
        new=`echo "$new" |perl -pi -e 's!KaddressbookGrantlee/!!g'`;
        new=`echo "$new" |perl -pi -e 's!QGpgME/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KDAV/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!Qt3DCore/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!Qt3DAnimation/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!Qt3DRender/!!g'`;
 
        
        newname=`echo "$new" |perl -pi -e 's!.h!!'`;
@@ -381,14 +384,14 @@ do
                            fi
                         ;;
                         QTest)
-                          number=`egrep "QCOMPARE|QVERIFY" $file|wc -l`;
+                          number=`egrep "QCOMPARE|QVERIFY|QTEST_GUILESS_MAIN|QTEST" $file|wc -l`;
                            if test $number = 0 ; then
                               remove_include;
                            fi
                         ;;
 
                         QtTest)
-                           number=`egrep "QCOMPARE|QVERIFY" $file|wc -l`;
+                           number=`egrep "QCOMPARE|QVERIFY|QTEST_GUILESS_MAIN|QTEST" $file|wc -l`;
                            if test $number = 0 ; then
                               remove_include;
                            fi
